Documentation
¶
Index ¶
Constants ¶
const GatewayCheckerType = "gateway"
const VirtualCheckerType = "virtualservice"
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Checker ¶
type Checker interface {
Check() ([]*models.IstioCheck, bool)
}
type DestinationRulesChecker ¶
type DestinationRulesChecker struct {
DestinationRules []kubernetes.IstioObject
MTLSDetails kubernetes.MTLSDetails
}
func (DestinationRulesChecker) Check ¶
func (in DestinationRulesChecker) Check() models.IstioValidations
type GatewayChecker ¶
type GatewayChecker struct {
GatewaysPerNamespace [][]kubernetes.IstioObject
Namespace string
}
func (GatewayChecker) Check ¶
func (g GatewayChecker) Check() models.IstioValidations
Check runs checks for the all namespaces actions as well as for the single namespace validations
type GroupChecker ¶
type GroupChecker interface {
Check() models.IstioValidations
}
type NoServiceChecker ¶
type NoServiceChecker struct {
Namespace string
IstioDetails *kubernetes.IstioDetails
Services []v1.Service
WorkloadList models.WorkloadList
GatewaysPerNamespace [][]kubernetes.IstioObject
}
func (NoServiceChecker) Check ¶
func (in NoServiceChecker) Check() models.IstioValidations
type VirtualServiceChecker ¶
type VirtualServiceChecker struct {
Namespace string
DestinationRules []kubernetes.IstioObject
VirtualServices []kubernetes.IstioObject
}
func (VirtualServiceChecker) Check ¶
func (in VirtualServiceChecker) Check() models.IstioValidations
An Object Checker runs all checkers for an specific object type (i.e.: pod, route rule,...) It run two kinds of checkers: 1. Individual checks: validating individual objects. 2. Group checks: validating behaviour between configurations.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.